caellion-python-commons: caellion.pycommons.encoding.base36.ValueTooLargeException Class Reference

caellion-python-commons

caellion.pycommons.encoding.base36.ValueTooLargeException Class Reference

This exception is raised when encountering an integer over maximum size of 16 bytes. More...

Inheritance diagram for caellion.pycommons.encoding.base36.ValueTooLargeException:

## Detailed Description

This exception is raised when encountering an integer over maximum size of 16 bytes.

Definition at line 38 of file base36.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/encoding/base36.py